@@ -25,7 +25,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 */
-//#define	DEBUG_PRINT
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -514,7 +513,7 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 		case VM68K_INST_MOVEMregtomem:
 			{
 				tVM68k_types datatype2;
-				tVM68k_uword bitmask;
+				tVM68k_uword bitmask=0;
 				datatype2=((opcode>>6)&1)?VM68K_LONG:VM68K_WORD;
 				retval=vm68k_resolve_ea(pVM68k,&next,datatype2,addrmode,reg2,VM68K_LEGAL_CONTROLALTERATEADDRESSING|VM68K_LEGAL_AM_PREDEC,&ea);
 				// special case: the memory decrement should only be performed when the bitmask says so
@@ -551,7 +550,7 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 		case VM68K_INST_MOVEMmemtoreg:
 			{
 				tVM68k_types datatype2;
-				tVM68k_uword bitmask;
+				tVM68k_uword bitmask=0;
 				datatype2=((opcode>>6)&1)?VM68K_LONG:VM68K_WORD;
 				retval=vm68k_resolve_ea(pVM68k,&next,datatype2,addrmode,reg2,VM68K_LEGAL_CONTROLADDRESSING|VM68K_LEGAL_AM_POSTINC,&ea);
 				// special case: the memory increment should only be performed when the bitmask says so
@@ -869,9 +868,13 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 		break;
 		default:
 		{
+#ifdef	DEBUG_PRINT
 			char tmp[64];
 			vm68k_get_instructionname(instruction,tmp);
 			printf("UNIMPLEMENTED opcode %04X = %s\n",opcode,tmp);
+#else
+			printf("UNIMPLEMENTED opcode %04X\n",opcode);
+#endif
 			retval=VM68K_NOK_UNKNOWN_INSTRUCTION;
 		}
 		break;
@@ -919,12 +922,11 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 }
 int vm68k_getNextOpcode(void* hVM68k,unsigned short* opcode)
 {
-	
+
 	tVM68k* pVM68k=(tVM68k*)hVM68k;
 	if (hVM68k==NULL) return VM68K_NOK_INVALID_PTR;
 	if (opcode==NULL) return VM68K_NOK_INVALID_PTR;
 	if (pVM68k->magic!=MAGICVALUE) return VM68K_NOK_INVALID_PARAMETER;
-	
 	*opcode=READ_INT16BE(pVM68k->pMem,pVM68k->pcr);
 	pVM68k->pcr+=2;
 #ifdef	DEBUG_PRINT
@@ -937,9 +939,15 @@ int vm68k_getNextOpcode(void* hVM68k,unsigned short* opcode)
 		printf("INST:%04X ",*opcode);
 		printf("CVZN:%d%d%d%d ", (pVM68k->sr>>0)&1,(pVM68k->sr>>1)&1,(pVM68k->sr>>2)&1,(pVM68k->sr>>3)&1);
 		printf("D:");
-		for (i=0;i<8;i++) printf("%08X:",pVM68k->d[i]);
+		for (i=0;i<8;i++) 
+		{
+			printf("%08X:",pVM68k->d[i]);
+		}
 		printf(" A:");
-		for (i=0;i<8;i++) printf("%08X:",pVM68k->a[i]);
+		for (i=0;i<8;i++) 
+		{
+			printf("%08X:",pVM68k->a[i]);
+		}
 
 		{
 			unsigned long long sum;
